@@ -1,5 +1,5 @@
 /* rmdir -- remove directories
-   Copyright (C) 90, 91, 1995-2002 Free Software Foundation, Inc.
+   Copyright (C) 90, 91, 1995-2002, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Options:
    -p, --parent		Remove any parent dirs that are explicitly mentioned
@@ -30,33 +30,25 @@
 #include "system.h"
 #include "dirname.h"
 #include "error.h"
-#include "quote.h"
+#include "quotearg.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "rmdir"
 
 #define AUTHORS "David MacKenzie"
 
-#ifndef EEXIST
-# define EEXIST 0
-#endif
-
-#ifndef ENOTEMPTY
-# define ENOTEMPTY 0
-#endif
-
 /* The name this program was run with. */
 char *program_name;
 
-/* If nonzero, remove empty parent directories. */
-static int empty_paths;
+/* If true, remove empty parent directories.  */
+static bool remove_empty_parents;
 
-/* If nonzero, don't treat failure to remove a nonempty directory
+/* If true, don't treat failure to remove a nonempty directory
    as an error.  */
-static int ignore_fail_on_non_empty;
+static bool ignore_fail_on_non_empty;
 
-/* If nonzero, output a diagnostic for every directory processed.  */
-static int verbose;
+/* If true, output a diagnostic for every directory processed.  */
+static bool verbose;
 
 /* For long options that have no equivalent short option, use a
    non-character as a pseudo short option, starting with CHAR_MAX + 1.  */
@@ -72,7 +64,7 @@ static struct option const longopts[] =
   {"ignore-fail-on-non-empty", no_argument, NULL,
    IGNORE_FAIL_ON_NON_EMPTY_OPTION},
 
-  {"path", no_argument, NULL, 'p'},
+  {"path", no_argument, NULL, 'p'},  /* Deprecated.  */
   {"parents", no_argument, NULL, 'p'},
   {"verbose", no_argument, NULL, 'v'},
   {GETOPT_HELP_OPTION_DECL},
@@ -80,65 +72,66 @@ static struct option const longopts[] =
   {NULL, 0, NULL, 0}
 };
 
-/* Return nonzero if ERROR_NUMBER is one of the values associated
+/* Return true if ERROR_NUMBER is one of the values associated
    with a failed rmdir due to non-empty target directory.  */
 
-static int
+static bool
 errno_rmdir_non_empty (int error_number)
 {
   return (error_number == RMDIR_ERRNO_NOT_EMPTY);
 }
 
-/* Remove any empty parent directories of PATH.
-   If PATH contains slash characters, at least one of them
-   (beginning with the rightmost) is replaced with a NUL byte.  */
+/* Remove any empty parent directories of DIR.
+   If DIR contains slash characters, at least one of them
+   (beginning with the rightmost) is replaced with a NUL byte.
+   Return true if successful.  */
 
-static int
-remove_parents (char *path)
+static bool
+remove_parents (char *dir)
 {
   char *slash;
-  int fail = 0;
+  bool ok = true;
 
-  strip_trailing_slashes (path);
+  strip_trailing_slashes (dir);
   while (1)
     {
-      slash = strrchr (path, '/');
+      slash = strrchr (dir, '/');
       if (slash == NULL)
 	break;
       /* Remove any characters after the slash, skipping any extra
 	 slashes in a row. */
-      while (slash > path && *slash == '/')
+      while (slash > dir && *slash == '/')
 	--slash;
       slash[1] = 0;
 
       /* Give a diagnostic for each attempted removal if --verbose.  */
       if (verbose)
-	error (0, 0, _("removing directory, %s"), path);
+	error (0, 0, _("removing directory, %s"), dir);
 
-      fail = rmdir (path);
+      ok = (rmdir (dir) == 0);
 
-      if (fail)
+      if (!ok)
 	{
 	  /* Stop quietly if --ignore-fail-on-non-empty. */
 	  if (ignore_fail_on_non_empty
 	      && errno_rmdir_non_empty (errno))
 	    {
-	      fail = 0;
+	      ok = true;
 	    }
 	  else
 	    {
-	      error (0, errno, "%s", quote (path));
+	      error (0, errno, "%s", quotearg_colon (dir));
 	    }
 	  break;
 	}
     }
-  return fail;
+  return ok;
 }
 
 void
 usage (int status)
 {
-  if (status != 0)
+  if (status != EXIT_SUCCESS)
     fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
@@ -152,8 +145,7 @@ Remove the DIRECTORY(ies), if they are empty.\n\
                   is non-empty\n\
 "), stdout);
       fputs (_("\
-  -p, --parents   remove DIRECTORY, then try to remove each directory\n\
-                  component of that path name.  E.g., `rmdir -p a/b/c' is\n\
+  -p, --parents   Remove DIRECTORY and its ancestors.  E.g., `rmdir -p a/b/c' is\n\
                   similar to `rmdir a/b/c a/b a'.\n\
   -v, --verbose   output a diagnostic for every directory processed\n\
 "), stdout);
@@ -167,7 +159,7 @@ Remove the DIRECTORY(ies), if they are empty.\n\
 int
 main (int argc, char **argv)
 {
-  int errors = 0;
+  bool ok = true;
   int optc;
 
   initialize_main (&argc, &argv);
@@ -178,22 +170,20 @@ main (int argc, char **argv)
 
   atexit (close_stdout);
 
-  empty_paths = 0;
+  remove_empty_parents = false;
 
   while ((optc = getopt_long (argc, argv, "pv", longopts, NULL)) != -1)
     {
       switch (optc)
 	{
-	case 0:			/* Long option. */
-	  break;
 	case 'p':
-	  empty_paths = 1;
+	  remove_empty_parents = true;
 	  break;
 	case IGNORE_FAIL_ON_NON_EMPTY_OPTION:
-	  ignore_fail_on_non_empty = 1;
+	  ignore_fail_on_non_empty = true;
 	  break;
 	case 'v':
-	  verbose = 1;
+	  verbose = true;
 	  break;
 	case_GETOPT_HELP_CHAR;
 	case_GETOPT_VERSION_CHAR (PROGRAM_NAME, AUTHORS);
@@ -204,35 +194,32 @@ main (int argc, char **argv)
 
   if (optind == argc)
     {
-      error (0, 0, _("too few arguments"));
+      error (0, 0, _("missing operand"));
       usage (EXIT_FAILURE);
     }
 
   for (; optind < argc; ++optind)
     {
-      int fail;
       char *dir = argv[optind];
 
       /* Give a diagnostic for each attempted removal if --verbose.  */
       if (verbose)
 	error (0, 0, _("removing directory, %s"), dir);
 
-      fail = rmdir (dir);
-
-      if (fail)
+      if (rmdir (dir) != 0)
 	{
 	  if (ignore_fail_on_non_empty
 	      && errno_rmdir_non_empty (errno))
 	    continue;
 
-	  error (0, errno, "%s", quote (dir));
-	  errors = 1;
+	  error (0, errno, "%s", quotearg_colon (dir));
+	  ok = false;
 	}
-      else if (empty_paths)
+      else if (remove_empty_parents)
 	{
-	  errors += remove_parents (dir);
+	  ok &= remove_parents (dir);
 	}
     }
 
-  exit (errors == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
+  exit (ok ? EXIT_SUCCESS : EXIT_FAILURE);
 }
