@@ -1,5 +1,5 @@
-/* tty -- print the path of the terminal connected to standard input
-   Copyright (C) 1990-2004 Free Software Foundation, Inc.
+/* tty -- print the name of the terminal connected to standard input
+   Copyright (C) 1990-2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* Displays "not a tty" if stdin is not a terminal.
    Displays nothing if -s option is given.
